# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class ModelFoundationEnum(str, Enum):
    """
    This is used to describe the foundational models used within POS.
    """

    """
    allowed enum values
    """
    GPT_3_DOT_5 = 'GPT_3.5'
    GPT_4 = 'GPT_4'
    T5 = 'T5'
    LLAMA_2_7_B = 'LLAMA_2_7B'
    LLAMA_2_13_B = 'LLAMA_2_13B'
    LLAMA_2_70_B = 'LLAMA_2_70B'
    CODE_LLAMA_2_7_B = 'CODE_LLAMA_2_7B'
    CODE_LLAMA_2_13_B = 'CODE_LLAMA_2_13B'
    CODE_LLAMA_2_70_B = 'CODE_LLAMA_2_70B'
    BARD = 'BARD'
    ALPACA_7_B = 'ALPACA_7B'
    ALPACA_13_B = 'ALPACA_13B'
    ALPACA_33_B = 'ALPACA_33B'
    ALPACA_65_B = 'ALPACA_65B'
    VICUNA_7_B = 'VICUNA_7B'
    VICUNA_13_B = 'VICUNA_13B'
    VICUNA_33_B = 'VICUNA_33B'
    VICUNA_65_B = 'VICUNA_65B'
    GUANACO_7_B = 'GUANACO_7B'
    GUANACO_13_B = 'GUANACO_13B'
    GUANACO_33_B = 'GUANACO_33B'
    GUANACO_65_B = 'GUANACO_65B'
    OPENLLAMA_7_B = 'OPENLLAMA_7B'
    OPENLLAMA_13_B = 'OPENLLAMA_13B'
    GORILLA_7_B = 'GORILLA_7B'
    GORILLA_13_B = 'GORILLA_13B'
    GORILLA_33_B = 'GORILLA_33B'
    GORILLA_65_B = 'GORILLA_65B'
    WIZARDLM_7_B = 'WIZARDLM_7B'
    WIZARDLM_13_B = 'WIZARDLM_13B'
    WIZARDLM_30_B = 'WIZARDLM_30B'
    YULANCHAT_13_B = 'YULANCHAT_13B'
    YULANCHAT_65_B = 'YULANCHAT_65B'
    REDPAJAMA_3_B = 'REDPAJAMA_3B'
    REDPAJAMA_7_B = 'REDPAJAMA_7B'
    REDPAJAMA_13_B = 'REDPAJAMA_13B'
    REDPAJAMA_33_B = 'REDPAJAMA_33B'
    REDPAJAMA_65_B = 'REDPAJAMA_65B'
    DOLLY_70_M = 'DOLLY_70M'
    DOLLY_160_M = 'DOLLY_160M'
    DOLLY_410_M = 'DOLLY_410M'
    DOLLY_1_B = 'DOLLY_1B'
    DOLLY_1_DOT_4_B = 'DOLLY_1.4B'
    DOLLY_2_DOT_8_B = 'DOLLY_2.8B'
    DOLLY_6_DOT_9_B = 'DOLLY_6.9B'
    DOLLY_12_B = 'DOLLY_12B'
    PYTHIA_70_M = 'PYTHIA_70M'
    PYTHIA_160_M = 'PYTHIA_160M'
    PYTHIA_410_M = 'PYTHIA_410M'
    PYTHIA_1_B = 'PYTHIA_1B'
    PYTHIA_1_DOT_4_B = 'PYTHIA_1.4B'
    PYTHIA_2_DOT_8_B = 'PYTHIA_2.8B'
    PYTHIA_6_DOT_9_B = 'PYTHIA_6.9B'
    PYTHIA_12_B = 'PYTHIA_12B'
    MOSS_7_B = 'MOSS_7B'
    MOSS_13_B = 'MOSS_13B'
    RMKV_LM_100_M = 'RMKV_LM_100M'
    RMKV_LM_400_M = 'RMKV_LM_400M'
    RMKV_LM_1_DOT_5_B = 'RMKV_LM_1.5B'
    RMKV_LM_3_B = 'RMKV_LM_3B'
    RMKV_LM_7_B = 'RMKV_LM_7B'
    RMKV_LM_14_B = 'RMKV_LM_14B'
    STARCODER_15_DOT_5_B = 'STARCODER_15.5B'
    WIZARDCODER_15_B = 'WIZARDCODER_15B'
    SANTACODER_1_DOT_1_B = 'SANTACODER_1.1B'
    TEXT_BISON = 'TEXT_BISON'
    TEXTEMBEDDING_GECKO = 'TEXTEMBEDDING_GECKO'
    CHAT_BISON = 'CHAT_BISON'
    CODE_BISON = 'CODE_BISON'
    CODECHAT_BISON = 'CODECHAT_BISON'
    CODE_GECKO = 'CODE_GECKO'
    DISTILROBERTA = 'DISTILROBERTA'
    MISTRAL_7_B = 'MISTRAL_7B'
    GEMINI = 'GEMINI'
    FAST_TEXT = 'FAST_TEXT'
    UNIXCODER = 'UNIXCODER'

    @classmethod
    def from_json(cls, json_str: str) -> ModelFoundationEnum:
        """Create an instance of ModelFoundationEnum from a JSON string"""
        return ModelFoundationEnum(json.loads(json_str))


