# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class TLPDirectedDiscoveryFilterEnum(str, Enum):
    """
    Code block type like function, class, abstract
    """

    """
    allowed enum values
    """
    FUNCTION = 'FUNCTION'
    METHOD = 'METHOD'
    CLASS = 'CLASS'
    STRUCT = 'STRUCT'
    ABSTRACT = 'ABSTRACT'
    COMMENT = 'COMMENT'
    IMPORT = 'IMPORT'
    IF = 'IF'
    LOOP = 'LOOP'
    RETURN = 'RETURN'

    @classmethod
    def from_json(cls, json_str: str) -> TLPDirectedDiscoveryFilterEnum:
        """Create an instance of TLPDirectedDiscoveryFilterEnum from a JSON string"""
        return TLPDirectedDiscoveryFilterEnum(json.loads(json_str))


