# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from pieces_client.models.embedded_model_schema import EmbeddedModelSchema
from pieces_client.models.externally_sourced_enum import ExternallySourcedEnum
from pieces_client.models.mailgun_metadata import MailgunMetadata

class PersonBasicType(BaseModel):
    """
    This is all optional properties around the most basic information around a non-pieces user.  A Basic type will NOT have a scope as it is not an actual pieces user.  # noqa: E501
    """
    var_schema: Optional[EmbeddedModelSchema] = Field(None, alias="schema")
    username: Optional[StrictStr] = Field(None, description="username or twitter handle...etc")
    name: Optional[StrictStr] = Field(None, description="This is the name of the basic user.")
    picture: Optional[StrictStr] = Field(None, description="this is a url picture representation of a user.")
    email: Optional[StrictStr] = Field(None, description="an email that was extracted.")
    sourced: Optional[ExternallySourcedEnum] = None
    url: Optional[StrictStr] = Field(None, description="This is a specific url that this basic user came from.")
    mailgun: Optional[MailgunMetadata] = None
    __properties = ["schema", "username", "name", "picture", "email", "sourced", "url", "mailgun"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PersonBasicType:
        """Create an instance of PersonBasicType from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_schema
        if self.var_schema:
            _dict['schema'] = self.var_schema.to_dict()
        # override the default output from pydantic by calling `to_dict()` of mailgun
        if self.mailgun:
            _dict['mailgun'] = self.mailgun.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PersonBasicType:
        """Create an instance of PersonBasicType from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PersonBasicType.parse_obj(obj)

        _obj = PersonBasicType.parse_obj({
            "var_schema": EmbeddedModelSchema.from_dict(obj.get("schema")) if obj.get("schema") is not None else None,
            "username": obj.get("username"),
            "name": obj.get("name"),
            "picture": obj.get("picture"),
            "email": obj.get("email"),
            "sourced": obj.get("sourced"),
            "url": obj.get("url"),
            "mailgun": MailgunMetadata.from_dict(obj.get("mailgun")) if obj.get("mailgun") is not None else None
        })
        return _obj


