# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictInt, StrictStr

class SystemExecutionCpuInformation(BaseModel):
    """
    SystemExecutionCpuInformation
    """
    count: StrictInt = Field(..., description="this is the number of cpus")
    brand: StrictStr = Field(..., description="this is the brand of cpu")
    frequency: StrictInt = Field(...)
    __properties = ["count", "brand", "frequency"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SystemExecutionCpuInformation:
        """Create an instance of SystemExecutionCpuInformation from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SystemExecutionCpuInformation:
        """Create an instance of SystemExecutionCpuInformation from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SystemExecutionCpuInformation.parse_obj(obj)

        _obj = SystemExecutionCpuInformation.parse_obj({
            "count": obj.get("count"),
            "brand": obj.get("brand"),
            "frequency": obj.get("frequency")
        })
        return _obj


