# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class ModelDownloadProgressStatusEnum(str, Enum):
    """
    Enum used for the status of the progress in downloading a model.
    """

    """
    allowed enum values
    """
    INITIALIZED = 'INITIALIZED'
    IN_MINUS_PROGRESS = 'IN-PROGRESS'
    COMPLETED = 'COMPLETED'
    FAILED = 'FAILED'
    UNKNOWN = 'UNKNOWN'

    @classmethod
    def from_json(cls, json_str: str) -> ModelDownloadProgressStatusEnum:
        """Create an instance of ModelDownloadProgressStatusEnum from a JSON string"""
        return ModelDownloadProgressStatusEnum(json.loads(json_str))


